@@ -274,6 +274,13 @@ namespace encode
             params.regionParams[12].presRegion = const_cast<PMOS_RESOURCE>(&m_vdencReadBatchBufferTU7[m_pipeline->m_currRecycledBufIdx][currentPass]);  // Region 12 - Input SLB Buffer (Input TU7)
         }
 
+        if (m_basicFeature->m_hevcSeqParams->LookaheadDepth && m_basicFeature->m_laDataBufferEnabled)
+        {
+            ENCODE_CHK_NULL_RETURN(m_basicFeature->m_LaDataBuffer);
+            ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnSkipResourceSync(m_basicFeature->m_LaDataBuffer));
+            params.regionParams[13].presRegion = m_basicFeature->m_LaDataBuffer;
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -686,8 +693,14 @@ namespace encode
         {
             auto original_TU = m_basicFeature->m_targetUsage;
             m_basicFeature->m_targetUsage = m_basicFeature->m_hevcSeqParams->TargetUsage = 7;
+
+            auto cqpFeature = dynamic_cast<HevcEncodeCqp *>(m_featureManager->GetFeature(HevcFeatureIDs::hevcCqpFeature));
+            ENCODE_CHK_NULL_RETURN(cqpFeature);
+            bool original_RDOQ = cqpFeature->IsRDOQEnabled();
+            cqpFeature->SetRDOQ(false);            
             ENCODE_CHK_STATUS_RETURN(ConstructBatchBufferHuCBRC(&m_vdencReadBatchBufferTU7[m_pipeline->m_currRecycledBufIdx][m_pipeline->GetCurrentPass()]));
             m_basicFeature->m_targetUsage = m_basicFeature->m_hevcSeqParams->TargetUsage = original_TU;
+            cqpFeature->SetRDOQ(original_RDOQ);
         }
 
         bool firstTaskInPhase = packetPhase & firstPacket;
